# PyPiSearch
[![Latest Release](https://img.shields.io/github/v/release/shidenko97/pypisearch)](https://github.com/shidenko97/pypisearch/releases/latest)
[![Downloads](https://pepy.tech/badge/pypisearch)](https://pepy.tech/project/pypisearch)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License](https://img.shields.io/github/license/shidenko97/pypisearch)](https://github.com/shidenko97/pypisearch/blob/master/LICENSE)

One more replacement of temporarily deprecated pip search command implemented on regular expressions and uses [pypi site](https://pypi.org/) search line.

## Install and run
- Clone this repo and run `python pypisearch <query>`
- Install it by pip `pip install pypisearch` and run `python -m pypisearch <query>`

### This fork provides `pypisearch` as a shell command

- Clone this repo, cd inside and run `pip install .`
- Run from anywhere `pypisearch <query>`.

